LHCb Development Tools
=======================
|pipeline status| |coverage report|

Set of tools used by the LHCb experiment for software development.


.. |pipeline status| image:: https://gitlab.cern.ch/lhcb-core/LbDevTools/badges/master/pipeline.svg
                     :target: https://gitlab.cern.ch/lhcb-core/LbDevTools/commits/master
.. |coverage report| image:: https://gitlab.cern.ch/lhcb-core/LbDevTools/badges/master/coverage.svg
                     :target: https://gitlab.cern.ch/lhcb-core/LbDevTools/commits/master
